@@ -479,7 +479,6 @@ class TinyMCE(widgets.Textarea):
         theme_advanced_resize_horizontal = False,
         theme_advanced_resizing = False,
         apply_source_formatting = False,
-        spellchecker_languages = "+Spanish=es",
         editor_deselector  = "mceNoEditor"
     )
 
@@ -492,6 +491,8 @@ class TinyMCE(widgets.Textarea):
         # copy the settings so each instance of the widget can modify them
         # without changing the other widgets (e.g. instance vs class variables)
         self.mce_settings = TinyMCE.mce_settings.copy()
+        self.mce_settings['spellchecker_languages'] = getattr(settings, 'TINYMCE_LANG_SPELLCHECKER', '+English=en')
+        self.mce_settings['language'] = getattr(settings, 'TINYMCE_LANG', 'en')
         self.mce_settings.update(extra_mce_settings)
 
     def update_settings(self, custom):
